=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2007-12-18 10:10:43 +0000
+++ loggerhead/history.py	2008-02-27 01:55:39 +0000
@@ -210,10 +210,7 @@
         self = cls()
         self._branch = branch
         self._last_revid = self._branch.last_revision()
-        if self._last_revid is not None:
-            self._revision_graph = branch.repository.get_revision_graph(self._last_revid)
-        else:
-            self._revision_graph = {}
+        self._revision_graph = branch.repository.get_revision_graph(self._last_revid)
 
         if name is None:
             name = self._branch.nick
@@ -223,7 +220,11 @@
         self._full_history = []
         self._revision_info = {}
         self._revno_revid = {}
-        self._merge_sort = bzrlib.tsort.merge_sort(self._revision_graph, self._last_revid, generate_revno=True)
+        if bzrlib.revision.is_null(self._last_revid):
+            self._merge_sort = []
+        else:
+            self._merge_sort = bzrlib.tsort.merge_sort(
+                self._revision_graph, self._last_revid, generate_revno=True)
         for (seq, revid, merge_depth, revno, end_of_merge) in self._merge_sort:
             self._full_history.append(revid)
             revno_str = '.'.join(str(n) for n in revno)
@@ -266,6 +267,10 @@
     def use_search_index(self, index):
         self._index = index
 
+    @property
+    def has_revisions(self):
+        return not bzrlib.revision.is_null(self.last_revid)
+
     @with_branch_lock
     def detach(self):
         # called when a new history object needs to be created, because the

=== modified file 'loggerhead/templates/browse.kid'
--- loggerhead/templates/browse.kid	2007-06-08 11:52:33 +0000
+++ loggerhead/templates/browse.kid	2008-02-27 01:55:39 +0000
@@ -34,7 +34,7 @@
             <tr>
             <td class="name"> <a href="${tg.url([ '/' + project.name, view.name ])}">${view.friendly_name}</a> </td>
             <td class="description"> ${view.description} </td>
-            <td class="last-update"> ${view.get_history().last_revid and util.ago(view.last_updated()) or "(no revisions)"} </td>
+            <td class="last-update"> ${view.get_history().has_revisions and util.ago(view.last_updated()) or "(no revisions)"} </td>
             <td class="feed">
                 <a href="${tg.url([ '/' + project.name, view.name, 'atom' ])}" title="atom feed">
                     <img src="${tg.url('/static/images/feed-icon-16x16.gif')}" alt="atom feed" />

=== modified file 'loggerhead/tests/test_simple.py'
--- loggerhead/tests/test_simple.py	2007-11-19 08:48:54 +0000
+++ loggerhead/tests/test_simple.py	2008-02-27 01:55:39 +0000
@@ -32,7 +32,7 @@
         self.tearDown()
 
     def setUp(self):
-        #logging.basicConfig(level=logging.DEBUG)
+        logging.basicConfig(level=logging.DEBUG)
         self.bzrbranch = None
         self.old_bzrhome = None
 

